declare module "hornet-js-logger/src/logger" {
	global {
	    interface Error {
	        toLog?: Function;
	    }
	}
	/**
	 * Construit un logger avec la catégory demandée
	 * @param category
	 * @param getLoggerFn La fonction permettant de charger le logger, cette fonction est différente
	 *            selon le client ou le serveur, c'est pour cette raison quelle doit être injectée
	 */
	export class Logger {
	    protected category: any;
	    protected log4jsLogger: any;
	    static log4js: any;
	    constructor(category: any);
	    static getLogger(category: any): Logger;
	    /**
	     * Récupère le logger. Si côté client alors utilise log4js, si côté serveur alors utilise
	     * log4js-node
	     */
	    buildLogger(category: string): void;
	    fatal(...args: any[]): any;
	    error(...args: any[]): any;
	    warn(...args: any[]): any;
	    info(...args: any[]): any;
	    debug(...args: any[]): any;
	    trace(...args: any[]): any;
	    deprecated(...args: any[]): any;
	    /**
	     * Récupère le nom de la fonction appelante,
	     * [mantis 0055464] en évitant de ramener l'appel du logger, qui ne nous intéresse pas :
	     * on remonte la pile d'appels en cherchant le code applicatif à l'origine de la log.
	     *
	     * Si la "vraie" fonction appelante n'est pas trouvée dans la pile,
	     * alors par défaut on utilise le paramètre d'entrée callStackSize
	     * qui indique le nombre arbitraire de niveaux à remonter dans la pile
	     * pour avoir la fonction appelante
	     *
	     */
	    static getFunctionName(callStackSize: number): string;
	    /**
	     * Appelle la fonction de journalisation du logger en ajoutant le nom de la fonction appelant et si
	     * disponible l'id de traitement
	     *
	     * @param niveau de log
	     * @param [, arg1[, arg2[, ...]]] Une liste d'arguments à logguer
	     */
	    log(level: string, ...args: any[]): void;
	    /**
	     * Appelle la fonction de journalisation du logger en ajoutant le nom de la fonction appelant et si
	     * disponible l'id de traitement
	     *
	     * @param niveau de log
	     * @param logArguments: Un tableau des objets (string, error ou object) à logguer
	     */
	    protected logInternal(level: string, logArguments: IArguments): void;
	    /**
	     * Méthode de recherche de stack depuis les arguments passés dans le logger
	     * @param args
	     * @returns {{}}
	     */
	    protected searchStack(args: any): {};
	    protected mappingObjectToString(arg: any): any;
	}
	
}

declare module "hornet-js-logger/test/logger-spec" {
	export {};
	
}

declare module "hornet-js-logger/src/decorators/logger" {
	/**
	 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
	 * <p/>
	 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
	 * <p/>
	 * Ce logiciel est un programme informatique servant à faciliter la création
	 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
	 * <p/>
	 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
	 * respectant les principes de diffusion des logiciels libres. Vous pouvez
	 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
	 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
	 * sur le site "http://www.cecill.info".
	 * <p/>
	 * En contrepartie de l'accessibilité au code source et des droits de copie,
	 * de modification et de redistribution accordés par cette licence, il n'est
	 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
	 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
	 * titulaire des droits patrimoniaux et les concédants successifs.
	 * <p/>
	 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
	 * associés au chargement,  à l'utilisation,  à la modification et/ou au
	 * développement et à la reproduction du logiciel par l'utilisateur étant
	 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
	 * manipuler et qui le réserve donc à des développeurs et des professionnels
	 * avertis possédant  des  connaissances  informatiques approfondies.  Les
	 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
	 * logiciel à leurs besoins dans des conditions permettant d'assurer la
	 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
	 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
	 * <p/>
	 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
	 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
	 * termes.
	 * <p/>
	 * <p/>
	 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
	 * <p/>
	 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
	 * <p/>
	 * This software is a computer program whose purpose is to facilitate creation of
	 * web application in accordance with french general repositories : RGI, RGS and RGAA.
	 * <p/>
	 * This software is governed by the CeCILL license under French law and
	 * abiding by the rules of distribution of free software.  You can  use,
	 * modify and/ or redistribute the software under the terms of the CeCILL
	 * license as circulated by CEA, CNRS and INRIA at the following URL
	 * "http://www.cecill.info".
	 * <p/>
	 * As a counterpart to the access to the source code and  rights to copy,
	 * modify and redistribute granted by the license, users are provided only
	 * with a limited warranty  and the software's author,  the holder of the
	 * economic rights,  and the successive licensors  have only  limited
	 * liability.
	 * <p/>
	 * In this respect, the user's attention is drawn to the risks associated
	 * with loading,  using,  modifying and/or developing or reproducing the
	 * software by the user in light of its specific status of free software,
	 * that may mean  that it is complicated to manipulate,  and  that  also
	 * therefore means  that it is reserved for developers  and  experienced
	 * professionals having in-depth computer knowledge. Users are therefore
	 * encouraged to load and test the software's suitability as regards their
	 * requirements in conditions enabling the security of their systems and/or
	 * data to be ensured and,  more generally, to use and operate it in the
	 * same conditions as regards security.
	 * <p/>
	 * The fact that you are presently reading this means that you have had
	 * knowledge of the CeCILL license and that you accept its terms.
	 *
	 */
	import "reflect-metadata";
	export interface LoggerOptions {
	    level?: LogLevels;
	    identification?: string;
	    message?: {
	        template: any;
	        values?: any;
	        remplaceUndef?: string;
	    };
	}
	export default function logger(options?: LoggerOptions): (target: any, key: any, descriptor?: any) => any;
	export enum LogLevels {
	    FATAL = "fatal",
	    ERROR = "error",
	    WARN = "warn",
	    INFO = "info",
	    DEBUG = "debug",
	    TRACE = "trace"
	}
	export interface Key {
	    key: string;
	    index: number;
	    keys: string[];
	}
	
}

declare module "hornet-js-logger/src/extend/appenders/browser-console-appender" {
	global {
	    var netscape: any;
	    var opera: any;
	    var log4jsLogger: any;
	    var Components: any;
	    interface Window {
	        opera?: any;
	    }
	}
	export {};
	
}

declare module "hornet-js-logger/src/extend/layout/simple-layout" {
	/**
	     * SimpleLayout consists of the level of the log statement, followed by " | "
	     * and then the log message itself. For example,
	     * <code>DEBUG - Hello world</code>
	     *
	     * @constructor
	     * @extends Log4js.Layout
	     * @author Stephan Strittmatter
	     */
	export class SimpleLayout {
	    LINE_SEP: any;
	    LINE_SEP_LEN: any;
	    constructor();
	    /**
	     * Implement this method to create your own layout format.
	     * @param {Log4js.LoggingEvent} loggingEvent loggingEvent to format
	     * @return formatted String
	     * @type String
	     */
	    format(loggingEvent: any): string;
	    /**
	     * Returns the content type output by this layout.
	     * @return The base class returns "text/plain".
	     * @type String
	     */
	    getContentType(): string;
	    /**
	     * @return Returns the header for the layout format. The base class returns null.
	     * @type String
	     */
	    getHeader(): string;
	    /**
	     * @return Returns the footer for the layout format. The base class returns null.
	     * @type String
	     */
	    getFooter(): string;
	}
	
}
